.. py:currentmodule:: rubin_scheduler.scheduler

.. _fbs:

=========
Scheduler
=========

The ``rubin_scheduler.scheduler`` module implements the scheduling
algorithms for the Vera C. Rubin Observatory's
Legacy Survey of Space and Time (LSST),
via the ``feature based scheduler`` (FBS).

.. toctree::

    Scheduler Overview <fbs-arch>

    Running a simulation <fbs-running>

    Simulation output schema <fbs-output-schema>